@@ -1,5 +1,5 @@
 package Bot::Backbone;
-$Bot::Backbone::VERSION = '0.160630';
+$Bot::Backbone::VERSION = '0.161950';
 use v5.10;
 use Moose();
 use Bot::Backbone::DispatchSugar();
@@ -101,7 +101,7 @@ Bot::Backbone - Extensible framework for building bots
 
 =head1 VERSION
 
-version 0.160630
+version 0.161950
 
 =head1 SYNOPSIS
 
@@ -153,7 +153,7 @@ version 0.160630
 
       # Basic echo command, with arguments
       command '!echo' => given_parameters {
-          argument echo_this => ( matching => qr/.*/ );
+          parameter echo_this => ( matching => qr/.*/ );
       } respond {
           my ($self, $message) = @_;
           $message->arguments->{echo_this};
