@@ -1,5 +1,5 @@
 package Bot::Backbone::Bot;
-$Bot::Backbone::Bot::VERSION = '0.160630';
+$Bot::Backbone::Bot::VERSION = '0.161950';
 use v5.10;
 use Moose;
 
@@ -25,6 +25,7 @@ has services => (
     traits      => [ 'Hash' ],
     handles     => {
         add_service      => 'set',
+        service_names    => 'keys',
         list_services    => 'values',
         destroy_services => 'clear',
         has_service      => 'defined',
@@ -33,15 +34,59 @@ has services => (
 );
 
 
+has initialized_services => (
+    is          => 'ro',
+    isa         => 'HashRef[Bool]',
+    required    => 1,
+    default     => sub { +{} },
+);
+
+
 sub bot { $_[0] }
 
 
+sub _ordered_services {
+    my $self = shift;
+
+    my %forest;
+    for my $pair ($self->meta->services_kv) {
+        my ($name, $config) = @$pair;
+
+        if ($config->{service}->does('Bot::Backbone::Service::Role::ChatConsumer')) {
+            $forest{ $name } = $config->{chat};
+        }
+        else {
+            $forest{ $name } = undef;
+        }
+    }
+
+    my @names;
+    for my $name (keys %forest) {
+        if (defined $forest{ $name }) {
+            my $depth = 1;
+            my $next_name = $forest{ $name };
+            while (defined($next_name = $forest{ $next_name })) {
+                $depth++;
+            }
+
+            $forest{ $name } = $depth;
+        }
+        else {
+            $forest{ $name } = 0;
+        }
+    }
+
+    return sort { $forest{ $a } <=> $forest{ $b } } keys %forest;
+}
+
 sub construct_services {
     my $self = shift;
 
     my $my_name = $self->meta->name;
 
-    for my $name ($self->meta->list_services) {
+    my @names = $self->_ordered_services;
+
+    for my $name ($self->_ordered_services) {
         my $service_config = $self->meta->services->{$name};
         next if defined $self->services->{$name};
 
@@ -57,11 +102,25 @@ sub construct_services {
 }
 
 
+sub initialize_services {
+  my $self = shift;
+
+    for my $name ($self->service_names) {
+        next if $self->initialized_services->{ $name };
+
+        $self->initialized_services->{ $name }++;
+
+        my $service = $self->get_service($name);
+        $service->initialize;
+    }
+}
+
+
 sub run {
     my $self = shift;
 
     $self->construct_services;
-    $_->initialize for ($self->list_services);
+    $self->initialize_services;
 
     $self->event_loop->run;
 }
@@ -89,7 +148,7 @@ Bot::Backbone::Bot - Provides backbone services to your bot
 
 =head1 VERSION
 
-version 0.160630
+version 0.161950
 
 =head1 SYNOPSIS
 
@@ -122,6 +181,11 @@ This is a hash of constructed services used by this bot. There should be a key
 in this hash matching every key in the same attribute in
 L<Bot::Backbone::Meta::Class>, once L</run> has been called.
 
+=head2 initialized_services
+
+This is a set containing the names of all the services that have been
+constructed and initialized.
+
 =head1 METHODS
 
 =head2 bot
@@ -136,6 +200,12 @@ This method iterates through the service configurations of the meta class and co
 
 You may run this prior to L</run> to construct your services prior to running. Normally, though, this method is called within L</run>.
 
+=head2 initialize_services
+
+  $bot->initialize_services;
+
+If more services are added to the bot later, this method may be called to initialize services after the new services have been constructed.
+
 =head2 run
 
   $bot->run;
